
==========================
Leonardo leonardo-keeweb
==========================

Serve Keeweb under Leonardo CMS.

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-keeweb

Read More
=========

* https://github.com/django-leonardo/django-leonardo
* https://github.com/antelle/keeweb